"""
Quantlab - Quantitative analysis tools for the Laakhay ecosystem
"""

__version__ = "0.1.0"
__author__ = "Laakhay Corporation"

def hello():
    print("Hello from Laakhay Quantlab!")

__all__ = ['hello']
